@@ -158,6 +158,14 @@ class KubernetesJobTask(luigi.Task):
         """
         return self.kubernetes_config.max_retrials
 
+    @property
+    def backoff_limit(self):
+        """
+        Maximum number of retries before considering the job as failed.
+        See: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/#pod-backoff-failure-policy
+        """
+        return 6
+
     @property
     def delete_on_success(self):
         """
@@ -322,6 +330,7 @@ class KubernetesJobTask(luigi.Task):
             },
             "spec": {
                 "activeDeadlineSeconds": self.active_deadline_seconds,
+                "backoffLimit": self.backoff_limit,
                 "template": {
                     "metadata": {
                         "name": self.uu_name
